==> SnappEmailApiClient-0.3.13.zip: SnappEmailApiClient-0.3.13/snapp_email/endpoints/location/ListOfLocationsPage_19Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import ListOfLocationsPage_19
from snapp_email.datacontract.utils import export_dict, fill


class ListOfLocationsPage_19Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, accept_type=None):
        """
        Retrieve options available for resource 'ListOfLocationsPage_19'.
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ListOfLocationsPage_19
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'location'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.location.list.page-v5.12+json',
            'Accept': 'application/vnd.4thoffice.location.list.page-v5.12+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers)
        
        return fill(ListOfLocationsPage_19, response.json())
    
    def create(self, obj, accept_type=None):
        """
        Post location record list.
        
        :param obj: Object to be persisted
        :type obj: ListOfLocationsPage_19
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ListOfLocationsPage_19
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'location'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.location.list.page-v5.12+json',
            'Accept': 'application/vnd.4thoffice.location.list.page-v5.12+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('post', endpoint, url_parameters, add_headers, data=json.dumps(data))
        
        return fill(ListOfLocationsPage_19, response.json())

==> SnappEmailApiClient-0.3.16.zip: SnappEmailApiClient-0.3.16/snapp_email/endpoints/location/ListOfLocationsPage_19Endpoint.py <==
"""
Auto generated code

"""

import json
from snapp_email.datacontract.classes import ListOfLocationsPage_19
from snapp_email.datacontract.utils import export_dict, fill


class ListOfLocationsPage_19Endpoint:
    def __init__(self, api_client):
        self.api_client = api_client
    
    def options(self, impersonate_user_id=None, accept_type=None):
        """
        Retrieve options available for resource 'ListOfLocationsPage_19'.
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ListOfLocationsPage_19
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'location'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.location.list.page-v5.12+json',
            'Accept': 'application/vnd.4thoffice.location.list.page-v5.12+json' if accept_type is None else accept_type,
        }
        response = self.api_client.api_call('options', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id)
        
        return fill(ListOfLocationsPage_19, response.json())
    
    def create(self, obj, impersonate_user_id=None, accept_type=None):
        """
        Post location record list.
        
        :param obj: Object to be persisted
        :type obj: ListOfLocationsPage_19
        
        :param impersonate_user_id: 
        :type impersonate_user_id: str
        
        :param accept_type: 
        :type accept_type: str
        
        :return: 
        :rtype: ListOfLocationsPage_19
        """
        url_parameters = {
        }
        endpoint_parameters = {
        }
        endpoint = 'location'.format(**endpoint_parameters)
        add_headers = {
            'Content-Type': 'application/vnd.4thoffice.location.list.page-v5.12+json',
            'Accept': 'application/vnd.4thoffice.location.list.page-v5.12+json' if accept_type is None else accept_type,
        }
        data = export_dict(obj)
        response = self.api_client.api_call('post', endpoint, url_parameters, add_headers, impersonate_user_id=impersonate_user_id, data=json.dumps(data))
        
        return fill(ListOfLocationsPage_19, response.json())
